
# -*- coding: utf-8 -*-

import requests
import time

from odoo import models, api
from odoo.addons.saas_worker.auth_util import SaasAuth
from odoo.addons.saas_worker.const import PLAUSIBLE_SAAS_SERVER, PLAUSIBLE_SAAS_SCRIPT, TIMEOUT
from odoo.addons.saas_worker.trials import create_plausible_site
from odoo.addons.saas_worker.util import version_gte

class Website(models.Model):
    _inherit = 'website'

    if version_gte('saas~15.4'):  # api.vacuum doesn't exists in old version, and plausible only in s15.4
        @api.autovacuum
        def _gc_plausible_keep_alive(self):
            if 'plausible_site' in self._fields:
                if not self.env['ir.config_parameter'].sudo().get_param('website.plausible_server'):
                    # we ping plausible website to show that db is alive
                    URL = PLAUSIBLE_SAAS_SERVER + "/api/event"
                    for website in self.search([('plausible_shared_key', '!=', False)]):
                        domain = website.plausible_site
                        requests.post(
                            URL, json=dict(domain=domain, name="Alive", url="https://%s" % domain),
                            auth=SaasAuth(), timeout=TIMEOUT,
                        )

        def _get_plausible_share_url(self):
            if 'plausible_shared_key' in self._fields:
                website = self.env.ref('website.default_website', False)
                if website and not website.plausible_shared_key and not website.plausible_site:
                    account_infos = create_plausible_site(self.env.cr.dbname, self.env.user.tz)
                    # be sure to have at least one ping for trial of less than 4h
                    cron_vacuum = self.env.ref('base.autovacuum_job', False)
                    if cron_vacuum:
                        cron_vacuum._trigger()
                    website.plausible_shared_key = account_infos.get('auth')
                    website.plausible_site = account_infos.get('domain')
                    # Ensure the Plausible ping appears in the stats
                    time.sleep(2)
            return super(Website, self)._get_plausible_share_url()

    def _get_plausible_script_url(self):
        return self.env['ir.config_parameter'].sudo().get_param('website.plausible_script', PLAUSIBLE_SAAS_SCRIPT)

    def _get_plausible_server(self):
        return self.env['ir.config_parameter'].sudo().get_param('website.plausible_server', PLAUSIBLE_SAAS_SERVER)

    if version_gte('15.0'):
        @api.model
        def configurator_init(self):
            r = super(Website, self).configurator_init()

            # Modules that will make you leave 1-app Free unless it's the
            # only module installed in addition to `website`.
            paid_website_apps_1appmax = [
                'website_hr_recruitment',
                'website_sale',
                'website_event_sale',
                'website_livechat',
                'website_slides',
                'website_google_map',
            ]

            # Modules that will always make you leave 1-app Free
            paid_website_apps_always = [
                'website_helpdesk',
                'website_appointment',
            ]

            WCF = self.env['website.configurator.feature']
            if version_gte('16.0'):
                WCF = WCF.search([])
            else:
                code = self.get_current_website().default_lang_id.code
                WCF = WCF.with_context(lang=code).search([])

            # Adding values to determine the 1AppFree state
            for f in r['features']:
                f['is_1appmax'] = WCF.browse(f['id']).module_id.name in paid_website_apps_1appmax
                f['is_always_paid'] = WCF.browse(f['id']).module_id.name in paid_website_apps_always
            return r
